@@ -1,6 +1,8 @@
+#include <config.h>
 #include <stdio.h>
 
 #include "giop-private.h"
+#include "giop-debug.h"
 
 const char giop_version_ids [GIOP_NUM_VERSIONS][2] = {
 	{1,0},
@@ -24,19 +26,20 @@ giop_init (void)
 	giop_recv_buffer_init ();
 }
 
-static void
-dump (FILE *out, guint8 const *ptr, guint32 len, guint32 offset)
+void
+giop_dump (FILE *out, guint8 const *ptr, guint32 len, guint32 offset)
 {
 	guint32 lp,lp2;
 	guint32 off;
 
 	for (lp = 0;lp<(len+15)/16;lp++) {
-		fprintf (out, "0x%4x ", offset + lp * 16);
+		fprintf (out, "0x%.4x: ", offset + lp * 16);
 		for (lp2=0;lp2<16;lp2++) {
+			fprintf (out, "%s", lp2%4?" ":"  ");
 			off = lp2 + (lp<<4);
-			off<len?fprintf (out, "%2x ", ptr[off]):fprintf (out, "XX ");
+			off<len?fprintf (out, "%.2x", ptr[off]):fprintf (out, "XX");
 		}
-		fprintf (out, "| ");
+		fprintf (out, " | ");
 		for (lp2=0;lp2<16;lp2++) {
 			off = lp2 + (lp<<4);
 			fprintf (out, "%c", off<len?(ptr[off]>'!'&&ptr[off]<127?ptr[off]:'.'):'*');
@@ -62,7 +65,7 @@ giop_dump_send (GIOPSendBuffer *send_buffer)
 
 	fprintf (stderr, "Outgoing IIOP data:\n");
 	while (nvecs-- > 0) {
-		dump (stderr, curvec->iov_base, curvec->iov_len, offset);
+		giop_dump (stderr, curvec->iov_base, curvec->iov_len, offset);
 		offset += curvec->iov_len;
 		curvec++;
 	}
@@ -83,7 +86,8 @@ giop_dump_recv (GIOPRecvBuffer *recv_buffer)
 
 	fprintf (stderr, "Incoming IIOP data: %s\n", status);
 
-	dump (stderr, recv_buffer->message_body,
-	      recv_buffer->msg.header.message_size +
-	      sizeof (GIOPMsgHeader), 0);
+	giop_dump (stderr, (guint8 *)recv_buffer, sizeof (GIOPMsgHeader), 0);
+
+	giop_dump (stderr, recv_buffer->message_body + 12,
+		   recv_buffer->msg.header.message_size, 12);
 }
