@@ -1,29 +1,59 @@
+#include <config.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <orbit/orbit.h>
 #include <orbit/poa/orbit-adaptor.h>
 
+#include "orbit-poa.h"
+#include "../orb-core/orbit-debug.h"
+
+int
+ORBit_adaptor_setup (ORBit_ObjectAdaptor adaptor,
+		     CORBA_ORB           orb)
+{
+	CORBA_long *tptr;
+	int         adaptor_id;
+
+	adaptor_id = orb->adaptors->len;
+
+	g_ptr_array_set_size (orb->adaptors, adaptor_id + 1);
+	g_ptr_array_index    (orb->adaptors, adaptor_id) = adaptor;
+
+	adaptor->adaptor_key._length  = ORBIT_ADAPTOR_KEY_LEN;
+	adaptor->adaptor_key._buffer  =
+		CORBA_sequence_CORBA_octet_allocbuf (ORBIT_ADAPTOR_KEY_LEN);
+	adaptor->adaptor_key._release = CORBA_TRUE;
+
+	tptr = (CORBA_long *) adaptor->adaptor_key._buffer;
+	*tptr = adaptor_id;
+	ORBit_genuid_buffer (adaptor->adaptor_key._buffer + sizeof (CORBA_long),
+			     ORBIT_RAND_DATA_LEN);
+
+	return adaptor_id;
+}
+
 static ORBit_ObjectAdaptor
 ORBit_adaptor_find (CORBA_ORB orb, ORBit_ObjectKey *objkey)
 {
 	ORBit_ObjectAdaptor   adaptor;
 	gint32                adaptorId;
 
-	if (objkey->_length < sizeof(gint32))
+	if (!objkey)
 		return NULL;
 
-	memcpy (&adaptorId, objkey->_buffer, sizeof(gint32));
+	if (objkey->_length < ORBIT_ADAPTOR_KEY_LEN)
+		return NULL;
+
+	memcpy (&adaptorId, objkey->_buffer, sizeof (gint32));
 
 	if (adaptorId < 0 || adaptorId >= orb->adaptors->len)
 		return NULL;
 
 	adaptor = g_ptr_array_index (orb->adaptors, adaptorId);
 
-	if (objkey->_length < adaptor->adaptor_key._length)
-		return NULL;
-
 	if (memcmp (objkey->_buffer, adaptor->adaptor_key._buffer,
-	            adaptor->adaptor_key._length))
+	            ORBIT_ADAPTOR_KEY_LEN))
 		return NULL;
 
 	return adaptor;
@@ -32,15 +62,20 @@ ORBit_adaptor_find (CORBA_ORB orb, ORBit_ObjectKey *objkey)
 void
 ORBit_handle_request (CORBA_ORB orb, GIOPRecvBuffer *recv_buffer)
 {
-	ORBit_ObjectAdaptor         adaptor;
-	ORBit_ObjectKey            *objkey;
+	ORBit_ObjectAdaptor  adaptor;
+	ORBit_ObjectKey     *objkey;
 
 	objkey = giop_recv_buffer_get_objkey (recv_buffer);
 	adaptor = ORBit_adaptor_find (orb, objkey);
 
-	if (!adaptor || !objkey)
+	if (!adaptor || !objkey) {
+		tprintf ("Error: failed to find adaptor or objkey for "
+			 "object while invoking method '%s'",
+			 giop_recv_buffer_get_opname (recv_buffer));
 		return;
-
+	}
+	dprintf (MESSAGES, "p %d: handle request '%s'\n", getpid (),
+		 giop_recv_buffer_get_opname (recv_buffer));
 	adaptor->handle_request (adaptor, recv_buffer, objkey);
 }
 
