@@ -54,7 +54,8 @@ testConst (void)
 	g_assert (test_CONST_FLOAT == 1234.56);
 	g_assert (test_CONST_DOUBLE == 1234.5678);
 	g_assert (test_CONST_LONG_DOUBLE == 1234.567891);
-	g_assert (test_FAVORITE_COLOUR == test_red);
+	g_assert (test_FAVORITE_SOUP == test_veggie);
+	g_assert (test_HORRIBLE_SOUP == test_oxtail);
 }
 
 static void
@@ -383,7 +384,8 @@ testIInterface (test_TestFactory   factory,
 	CORBA_free (iinterface);
 
 	tcs = ORBit_small_get_types (TYPELIB_NAME);
-	g_assert (find_tc (tcs, "IDL:orbit/test/Colour:1.0"));
+	g_assert (find_tc (tcs, "IDL:orbit/test/Soup:1.0"));
+	g_assert (find_tc (tcs, "IDL:orbit/test/EnumUnion/Colour:1.0"));
 	g_assert (find_tc (tcs, "IDL:orbit/test/ArrayUnion:1.0"));
 	CORBA_free (tcs);
 }
@@ -747,7 +749,7 @@ testMiscUnions (test_TestFactory   factory,
 		g_free (tmp);
 	}
 
-	g_assert (retn._d == test_red);
+	g_assert (retn._d == test_EnumUnion_red);
 	g_assert (retn._u.x == constants_LONG_IN);
 
 	CORBA_free (outArg);
@@ -769,22 +771,22 @@ testFixedLengthArray (test_TestFactory   factory,
   objref = test_TestFactory_getArrayServer (factory, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inArg[i] = constants_SEQ_LONG_IN[i];
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inoutArg[i] = constants_SEQ_LONG_INOUT_IN[i];
 
   retn = test_ArrayServer_opLongArray (objref, inArg, inoutArg, outArg, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (inArg[i]==constants_SEQ_LONG_IN[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (inoutArg[i]==constants_SEQ_LONG_INOUT_OUT[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (outArg[i]==constants_SEQ_LONG_OUT[i]);
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	g_assert (retn[i]==constants_SEQ_LONG_RETN[i]);
 
   CORBA_free (retn);
@@ -806,19 +808,19 @@ testVariableLengthArray (test_TestFactory   factory,
   objref = test_TestFactory_getArrayServer (factory, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inArg[i] = CORBA_string_dup (constants_SEQ_STRING_IN[i]);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	inoutArg[i] = CORBA_string_dup (constants_SEQ_STRING_INOUT_IN[i]);
 
   retn = test_ArrayServer_opStrArray (objref, inArg, inoutArg, &outArg, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
 	CORBA_free (inArg[i]); 
 
-  for (i=0;i<constants_SEQLEN;i++)
+  for (i=0;i<test_SequenceLen;i++)
         CORBA_free (inoutArg[i]);
 
   CORBA_free (outArg);
@@ -1096,6 +1098,7 @@ testAnyEquivalence (test_TestFactory   factory,
 	bseq->_buffer [1]._d   = aseq->_buffer [1]._d   = 2;
 	aseq->_buffer [1]._u.y = CORBA_string_dup ("blah");
 	bseq->_buffer [1]._u.y = CORBA_string_dup ("blah");
+
 	bseq->_buffer [2]._d   = aseq->_buffer [2]._d   = 55;
 	bseq->_buffer [2]._u.w = aseq->_buffer [2]._u.w = constants_LONG_IN;
 
@@ -1248,7 +1251,7 @@ testMisc (test_TestFactory   factory,
 		g_assert (!strcmp (ev->_id, "IDL:CORBA/BAD_OPERATION:1.0"));
 		CORBA_exception_free (ev);
 	}
-	
+
 	g_assert (ORBit_copy_value (NULL, TC_CORBA_boolean) == NULL);
 
 	objref = test_TestFactory_getBasicServer (factory, ev);
@@ -1257,6 +1260,20 @@ testMisc (test_TestFactory   factory,
 	g_assert (CORBA_Object_is_a (objref, "IDL:orbit/test/BasicServer:1.0", ev));
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
+	{ /* IOR stringification */
+		CORBA_char *ior;
+		CORBA_Object o2;
+
+		ior = CORBA_ORB_object_to_string (global_orb, factory, &ev);
+		g_assert (ev->_major == CORBA_NO_EXCEPTION);
+
+		o2 = CORBA_ORB_string_to_object (global_orb, ior, &ev);
+		g_assert (ev->_major == CORBA_NO_EXCEPTION);
+		
+		g_assert (o2 == factory);
+		CORBA_Object_release (o2, &ev);
+	}
+	
 	test_BasicServer_noImplement (objref, ev);
 	g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
 	g_assert (!strcmp (ev->_id, "IDL:CORBA/NO_IMPLEMENT:1.0"));
